@@ -3,17 +3,18 @@
 """
 from payton.scene.gui.base import Hud, Rectangle, Shape2D, Text
 from payton.scene.gui.help import info_box
-from payton.scene.gui.window import Button, Panel, Theme, Window, WindowAlignment
+from payton.scene.gui.window import Button, EditBox, Panel, Theme, Window, WindowAlignment
 
 __all__ = [
-    "Shape2D",
-    "Rectangle",
-    "Text",
+    "Button",
+    "EditBox",
     "Hud",
+    "info_box",
+    "Panel",
+    "Rectangle",
+    "Shape2D",
+    "Text",
+    "Theme",
     "Window",
     "WindowAlignment",
-    "Panel",
-    "Button",
-    "Theme",
-    "info_box",
 ]
